rm(list=ls())
# set working directory to source file location
source('analysis_customFunctions.R')
library(ggplot2)

### TRAINING PHASE ANALYSES
allTraining <- read.csv('DVCMG_trainingPhaseData_final.csv')
training_summary_RT <- summarizeByCondition(allTraining, 'RT')
training_summary_PC <- summarizeByCondition(allTraining, 'PC')

## Table 1: Mean (standard deviation) for training-phase conditions
print(paste('Reliable RT: ',round(mean(training_summary_RT$reliable*1000),2),' (',round(sd(training_summary_RT$reliable*1000),2),')', sep=''))
print(paste('Unreliable RT: ',round(mean(training_summary_RT$unreliable*1000),2),' (',round(sd(training_summary_RT$unreliable*1000),2),')', sep=''))
print(paste('Reliable PC: ',round(mean(training_summary_PC$reliable),4),' (',round(sd(training_summary_PC$reliable),2),')', sep=''))
print(paste('Unreliable PC: ',round(mean(training_summary_PC$unreliable),4),' (',round(sd(training_summary_PC$unreliable),2),')', sep=''))

## Statistics reported in Figure 1
printStats(training_summary_PC$reliable-training_summary_PC$unreliable) # Fig. 1B (top)
printStats(training_summary_RT$reliable-training_summary_RT$unreliable) # Fig. 1B (bottom)

### TEST PHASE ANALYSES
allTest <- read.csv('DVCMG_testPhaseData_final.csv')

# Proportion of trials with any saccades to distractor
test_summary_ASD <- summarizeByCondition(allTest, 'ASD')
# One-way RM ANOVA
doRepeatedMeasuresANOVA_oneWay(test_summary_ASD)
# Follow-up t-tests
printStats(test_summary_ASD$reliable-test_summary_ASD$none)
printStats(test_summary_ASD$unreliable-test_summary_ASD$none)
printStats(test_summary_ASD$unreliable-test_summary_ASD$reliable)

# Mean RT, correct trials only
test_summary_RT <- summarizeByCondition(allTest, 'RT')
# One-way RM ANOVA
doRepeatedMeasuresANOVA_oneWay(test_summary_RT)

# Proportion correct (missed deadline trials counted as incorrect)
test_summary_PC <- summarizeByCondition(allTest, 'PC')
# One-way RM ANOVA
doRepeatedMeasuresANOVA_oneWay(test_summary_PC)

# Individual differences
cor.test(test_summary_ASD$unreliable-test_summary_ASD$reliable, test_summary_RT$unreliable-test_summary_RT$reliable)

## Table 2: Mean (standard deviation) for test-phase conditions.
# Proportion of saccades to distractor
r1 <- paste('Distractor-absent: ',round(mean(test_summary_ASD$none,na.rm=TRUE),4),' (',round(sd(test_summary_ASD$none,na.rm=TRUE),2),')', sep='')
r2 <- paste('Reliably pre-cued: ',round(mean(test_summary_ASD$reliable,na.rm=TRUE),4),' (',round(sd(test_summary_ASD$reliable,na.rm=TRUE),2),')', sep='')
r3 <- paste('Unreliably pre-cued: ',round(mean(test_summary_ASD$unreliable,na.rm=TRUE),4),' (',round(sd(test_summary_ASD$unreliable,na.rm=TRUE),2),')', sep='')
print(paste(r1, r2, r3))

# Accuracy (proportion correct)
r1 <- paste('Distractor-absent: ',round(mean(test_summary_PC$none),4),' (',round(sd(test_summary_PC$none),2),')', sep='')
r2 <- paste('Reliable PC: ',round(mean(test_summary_PC$reliable),4),' (',round(sd(test_summary_PC$reliable),2),')', sep='')
r3 <- paste('Unreliable PC: ',round(mean(test_summary_PC$unreliable),4),' (',round(sd(test_summary_PC$unreliable),2),')', sep='')
print(paste(r1, r2, r3))

# Response time (ms)
r1 <- paste('Distractor-absent: ',round(mean(test_summary_RT$none*1000),2),' (',round(sd(test_summary_RT$none*1000),2),')', sep='')
r2 <- paste('Reliable RT: ',round(mean(test_summary_RT$reliable*1000),2),' (',round(sd(test_summary_RT$reliable*1000),2),')', sep='')
r3 <- paste('Unreliable RT: ',round(mean(test_summary_RT$unreliable*1000),2),' (',round(sd(test_summary_RT$unreliable*1000),2),')', sep='')
print(paste(r1, r2, r3))

# Generalized linear mixed-effects modeling with hierarchical Bayesian estimation
trialHasSaccade <- !is.na(allTest$firstSacLocation.abs)
trialHasInformationDistractor <- allTest$distractorIsPresent==1
df <- allTest[trialHasSaccade & trialHasInformationDistractor,]
subjs <- sort(unique(df$subjID))
for (s in 1:length(subjs)){df$ID[df$subjID==subjs[s]] <- s}
anySaccadeToDistractor <- data.frame(ID=df$ID, 
                                     saccToD=df$distractorIsAttended, 
                                     isIIA=df$distractorIsUnreliable)
# NOTE: If you have the rethinking library, with Stan correctly installed, and want to re-run the models, change reRunModels to TRUE on the next line.
# To see the exact values in the paper, you will need to evaluate using the saved models
reRunModels <- FALSE
if (reRunModels==TRUE){
  library(rethinking)
  startingVals <- logit(aggregate(anySaccadeToDistractor$saccToD, list(ID=anySaccadeToDistractor$ID), mean, na.rm=TRUE)$x)
  model1 <- ulam(alist(
    saccToD ~ dbinom(1,p),
    logit(p) <-  b0[ID] + b1*isIIA,
    b0[ID] ~ dnorm(mu,sig),
    mu ~ dnorm(0,1),
    sig ~ dexp(1),
    b1 ~ dnorm(0,1)),
    data=anySaccadeToDistractor, iter=1e3, chains=4, cores=4, control=list(max_treedepth=15),
    start = list(b0=startingVals, b1=0))
  write.csv(precis(model1, prob=0.95, depth=2), file='model1_summary.csv')
  samples_model1 <- extract.samples(model1)
  save(model1,file='model1.RData')
  save(samples_model1,file='samples_model1.RData')}

# Load in saved model samples
load(file='samples_model1.RData')
print(paste('b1 mean: ', round(mean(samples_model1$b1), digits=4)))
print(paste('95% credible interval: ',round(quantile(samples_model1$b1, prob=0.025), digits=4),'-',round(quantile(samples_model1$b1, prob=0.975), digits=4)))
print(paste('b1 > 0: ',mean(samples_model1$b1>0)*100,'%',sep=''))
model1_summary <- read.csv('model1_summary.csv')
print(paste('Max Rhat: ', round(max(model1_summary$Rhat4), digits=4)))
plotPosterior(samples_model1$b1, color='cyan', opacity=.2, xLim=c(-.05, .22), yLim = c(0,15))
#ggsave(filename = 'Fig1C_B1.png', width=2, height=2, bg = "white")

probSacc.R <- plogis(samples_model1$b0) # convert to probability space
probSacc.U <- array(dim=c(nrow(probSacc.R), ncol(probSacc.R)))
for (c in 1:ncol(samples_model1$b0)){
  # add the fixed effect to each random effect and convert to probability space
  probSacc.U[,c] <- plogis(samples_model1$b0[,c]+samples_model1$b1)
}
print(paste('redundant-information: ',round(mean(rowMeans(probSacc.R)), digits = 4)))
print(paste('instrumental-information: ',round(mean(rowMeans(probSacc.U)), digits = 4)))
probSacc.delta <- probSacc.U - probSacc.R
print(paste('deltaP > 0: ',mean(rowMeans(probSacc.delta)>0)*100, '%', sep=''))
propSacc.R <- mean(anySaccadeToDistractor$saccToD[anySaccadeToDistractor$isIIA==0])
propSacc.U <- mean(anySaccadeToDistractor$saccToD[anySaccadeToDistractor$isIIA==1])
plotPosterior(rowMeans(probSacc.delta), realVal = propSacc.U-propSacc.R, color='gray', opacity=.2, xLim=c(-.01, .05), yLim = c(0,100))
#ggsave(filename = 'Fig1C_deltaP.png', width=2, height=2, bg = "white")

# non-Bayesian generalized linear mixed-effects model, Results, Footnote 3
library(lme4)
summary(glmer(saccToD ~ isIIA + (1|ID), data = anySaccadeToDistractor, family = binomial))

# Supplementary Results, Saccadic Variability 
propSacc <- aggregate(!is.na(allTest$firstSacLocation.abs), list(ID=allTest$subjID), mean, na.rm=TRUE)$x
print(paste('propSacc mean: ', round(mean(propSacc*100), digits=2), '%', sep=''))
print(paste('propSacc min: ', round(min(propSacc*100), digits=2), sep=''))
print(paste('propSacc max: ', round(max(propSacc*100), digits=2), sep=''))
print(paste('propSacc median: ', round(median(propSacc*100), digits=2), '%', sep=''))

# Supplementary Results, Proportion of “First Saccades” to Distractor
test_summary_FSD <- summarizeByCondition(allTest, 'FSD')
# One-way RM ANOVA
doRepeatedMeasuresANOVA_oneWay(test_summary_FSD)
# Follow-up t-tests
printStats(test_summary_FSD$reliable-test_summary_FSD$none)
printStats(test_summary_FSD$unreliable-test_summary_FSD$none)
printStats(test_summary_FSD$unreliable-test_summary_FSD$reliable)
# Table S1 Proportion of saccades to distractor
r1 <- paste('Distractor-absent: ',round(mean(test_summary_FSD$none,na.rm=TRUE),4),' (',round(sd(test_summary_FSD$none,na.rm=TRUE),2),')', sep='')
r2 <- paste('Reliably pre-cued: ',round(mean(test_summary_FSD$reliable,na.rm=TRUE),4),' (',round(sd(test_summary_FSD$reliable,na.rm=TRUE),2),')', sep='')
r3 <- paste('Unreliably pre-cued: ',round(mean(test_summary_FSD$unreliable,na.rm=TRUE),4),' (',round(sd(test_summary_FSD$unreliable,na.rm=TRUE),2),')', sep='')
print(paste(r1, r2, r3))

# Supplementary Results, RT and Oculomotor Capture, Bayesian Modeling
trialHasSaccade <- !is.na(allTest$firstSacLocation.abs)
trialHasInformationDistractor <- allTest$distractorIsPresent==1
trialWasCorrect <- allTest$correctTrial==1
df <- allTest[trialHasSaccade & trialHasInformationDistractor & trialWasCorrect,]
subjs <- sort(unique(df$subjID))
for (s in 1:length(subjs)){df$ID[df$subjID==subjs[s]] <- s}
dat_list <- data.frame(RT=df$RT, 
                       isIIA=df$distractorIsUnreliable,
                       isAttended=df$distractorIsAttended,
                       ID=df$ID)
reRunModels <- FALSE
if (reRunModels==TRUE){
  library(rethinking)
  uniqueSubjs=unique(dat_list$ID)
  fitRTs<- ulam(
    alist(
      RT ~ dlnorm(mu,sig),
      mu <- b0_mu[ID] + b1_mu*isIIA + b2_mu*isAttended + b3_mu*isIIA*isAttended,
      sig <- b0_sig[ID]+ b1_sig*isIIA + b2_sig*isAttended + b3_sig*isIIA*isAttended,
      b0_mu[ID] ~ dnorm(b0_muM,b0_muS),
      b0_muM ~ dnorm(0,1),
      b0_muS ~ dexp(1),
      b1_mu ~ dnorm(0,1),
      b2_mu ~ dnorm(0,1),
      b3_mu ~ dnorm(0,1),
      b0_sig[ID] ~ dnorm(b0_sigM,b0_sigS),
      b0_sigM ~ dnorm(0,1),
      b0_sigS ~ dexp(1),
      b1_sig ~ dnorm(0,1),
      b2_sig ~ dnorm(0,1),
      b3_sig ~ dnorm(0,1)
    ) , data=dat_list, iter=1e3, chains=4, cores=4, start = list(b0_mu=rep(0,length(uniqueSubjs)),
                                                                 b0_sig=rep(1,length(uniqueSubjs)),
                                                                 b1_mu=0,b1_sig=0, b2_mu=0,b2_sig=0, b3_mu=0,b3_sig=0))
  write.csv(precis(fitRTs, prob=0.95, depth=2), file='model2_summary.csv')
  samples_model2 <- extract.samples(fitRTs)
  save(fitRTs,file='model2.RData')
  save(samples_model2,file='samples_model2.RData')}

# Load in saved model samples
load(file='samples_model2.RData')
print(paste('b3_mu mean: ', round(mean(samples_model2$b3_mu), digits=4)))
print(paste('95% credible interval: ',round(quantile(samples_model2$b3_mu, prob=0.025), digits=4),'-',round(quantile(samples_model2$b3_mu, prob=0.975), digits=4)))
print(paste('b3_mu > 0: ',mean(samples_model2$b3_mu>0)*100, '%', sep=''))
model2_summary <- read.csv('model2_summary.csv')
print(paste('Max Rhat: ', round(max(model2_summary$Rhat4), digits=4)))

# condition means in milliseconds
mean.UnattRI <- exp(samples_model2$b0_mu+((samples_model2$b0_sig^2)/2))*1000
mean.UnattII <- array(dim=c(nrow(mean.UnattRI), ncol(mean.UnattRI)))
mean.AttRI <- array(dim=c(nrow(mean.UnattRI), ncol(mean.UnattRI)))
mean.AttII <- array(dim=c(nrow(mean.UnattRI), ncol(mean.UnattRI)))
for (c in 1:ncol(mean.UnattRI)){
  mean.UnattII[,c] <- exp((samples_model2$b0_mu[,c]+samples_model2$b1_mu)+(((samples_model2$b0_sig[,c]+samples_model2$b1_sig)^2)/2))*1000
  mean.AttRI[,c] <- exp((samples_model2$b0_mu[,c]+samples_model2$b2_mu)+(((samples_model2$b0_sig[,c]+samples_model2$b2_sig)^2)/2))*1000
  mean.AttII[,c] <- exp((samples_model2$b0_mu[,c]+samples_model2$b1_mu+samples_model2$b2_mu+samples_model2$b3_mu)+(((samples_model2$b0_sig[,c]+samples_model2$b1_sig+samples_model2$b2_sig+samples_model2$b3_sig)^2)/2))*1000
}
print(paste('attended and II-associated: ',round(mean(rowMeans(mean.AttII)), digits=1)))
print(paste('unattended and II-associated: ',round(mean(rowMeans(mean.UnattII)), digits=1)))
print(paste('attended and RI-associated: ',round(mean(rowMeans(mean.AttRI)), digits=1)))
print(paste('unattended and RI-associated: ',round(mean(rowMeans(mean.UnattRI)), digits=1)))

rt.interaction <- rowMeans((mean.AttII-mean.UnattII)-(mean.AttRI-mean.UnattRI))
print(paste('95% credible interval: ',round(quantile(rt.interaction, prob=0.025), digits=4),'-',round(quantile(rt.interaction, prob=0.975), digits=4)))
m1 <- mean(dat_list$RT[dat_list$isAtt==1&dat_list$isIIA==1]*1000)
m2 <- mean(dat_list$RT[dat_list$isAtt==0&dat_list$isIIA==1]*1000)
m3 <- mean(dat_list$RT[dat_list$isAtt==1&dat_list$isIIA==0]*1000)
m4 <- mean(dat_list$RT[dat_list$isAtt==0&dat_list$isIIA==0]*1000)
plotPosterior(rt.interaction, realVal = ((m1-m2)-(m3-m4)), color='gray', opacity=.2, xLim=c(-10, 35), yLim = c(0,.1))
#ggsave(filename = 'RTinteractionInMS.png', width=2, height=2, bg = "white")

  